@@ -54,7 +54,7 @@ cache_close(struct cache *ca)
     for (i = 0; i < HASH_SIZE; ++i)
 	while (not dl_empty(ca->hash + i))
 	{
-	    cp = $ ca->hash[i].first;
+	    cp = PTR ca->hash[i].first;
 	    dl_remove(cp->node);
 	    free(cp);
 	}
@@ -68,7 +68,7 @@ cache_reset(struct cache *ca)
     int i;
 
     for (i = 0; i < HASH_SIZE; ++i)
-	for (cp = $ ca->hash[i].first; cpn = $ cp->node->next; cp = cpn)
+	for (cp = PTR ca->hash[i].first; cpn = PTR cp->node->next; cp = cpn)
 	    if (cp->page->pgno / 256 != 9) // don't remove help pages
 	    {
 		dl_remove(cp->node);
@@ -91,7 +91,7 @@ cache_get(struct cache *ca, int pgno, int subno)
     struct cache_page *cp;
     int h = hash(pgno);
 
-    for (cp = $ ca->hash[h].first; cp->node->next; cp = $ cp->node->next)
+    for (cp = PTR ca->hash[h].first; cp->node->next; cp = PTR cp->node->next)
 	if (cp->page->pgno == pgno)
 	    if (subno == ANY_SUB || cp->page->subno == subno)
 	    {
@@ -114,7 +114,7 @@ cache_put(struct cache *ca, struct vt_page *vtp)
     struct cache_page *cp;
     int h = hash(vtp->pgno);
     
-    for (cp = $ ca->hash[h].first; cp->node->next; cp = $ cp->node->next)
+    for (cp = PTR ca->hash[h].first; cp->node->next; cp = PTR cp->node->next)
 	if (cp->page->pgno == vtp->pgno && cp->page->subno == vtp->subno)
 	    break;
 
@@ -155,7 +155,7 @@ cache_lookup(struct cache *ca, int pgno, int subno)
     struct cache_page *cp;
     int h = hash(pgno);
 
-    for (cp = $ ca->hash[h].first; cp->node->next; cp = $ cp->node->next)
+    for (cp = PTR ca->hash[h].first; cp->node->next; cp = PTR cp->node->next)
 	if (cp->page->pgno == pgno)
 	    if (subno == ANY_SUB || cp->page->subno == subno)
 		return cp->page;
@@ -247,7 +247,7 @@ cache_open(void)
     ca->npages = 0;
     ca->op = &cops;
 
-    for (vtp = help_pages; vtp->pgno >= 0; vtp++)
+    for (vtp = help_pages; vtp < help_pages + nr_help_pages; vtp++)
 	cache_put(ca, vtp);
 
     return ca;
