@@ -89,7 +89,7 @@ prepare_colour_matrix(/*struct export *e,*/
 
 static int ppm_output(struct export *e, char *name, struct fmt_page *pg);
 
-struct export_module export_ppm[1] =	// exported module definition
+struct export_module export_ppm =	// exported module definition
 {
     "ppm",			// id
     "ppm",			// extension
@@ -173,7 +173,7 @@ struct png_data			// private data in struct export
     int compression;
 };
 
-struct export_module export_png[1] =	// exported module definition
+struct export_module export_png =	// exported module definition
 {
     "png",			// id
     "png",			// extension
