@@ -79,6 +79,6 @@ struct vt_page help_pages[] =
     { 0x999, 0, -1, 0, 0, (1<<26)-1, {
 #include "vt999.out"
     }, FLOF_DATA },
-
-    { -1, 0 }
 };
+
+const int nr_help_pages = NELEM(help_pages);
