@@ -19,4 +19,4 @@ void init_enhance(struct enhance *eh);
 void add_enhance(struct enhance *eh, int dcode, u32 *data);
 void enhance(struct enhance *eh, struct vt_page *vtp);
 
-#endif LANG_H
+#endif /*LANG_H*/
