@@ -21,11 +21,14 @@ static int rawbuf_size;		// its current size
 /***** bttv api *****/
 
 #define BASE_VIDIOCPRIVATE	192
-#define BTTV_VERSION		_IOR('v' , BASE_VIDIOCPRIVATE+6, int)
 #define BTTV_VBISIZE		_IOR('v' , BASE_VIDIOCPRIVATE+8, int)
 
 /***** v4l2 vbi-api *****/
 
+#define V4L2_PIX_FMT_GREY		0x59455247
+#define V4L2_BUF_TYPE_VBI_CAPTURE       0x00000004
+#define VIDIOC_G_FMT			_IOWR('V',  4, struct v4l2_format)
+
 struct v4l2_vbi_format
 {
     u32 sampling_rate;		/* in 1 Hz */
@@ -43,15 +46,12 @@ struct v4l2_format
     u32	type;			/* V4L2_BUF_TYPE_* */
     union
     {
+	void *alignment_dummy;
 	struct v4l2_vbi_format vbi;	/*  VBI data  */
 	u8 raw_data[200];		/* user-defined */
     } fmt;
 };
 
-#define V4L2_VBI_SF_UBYTE	1
-#define V4L2_BUF_TYPE_VBI       0x00000009
-#define VIDIOC_G_FMT		_IOWR('V',  4, struct v4l2_format)
-
 /***** end of api definitions *****/
 
 
@@ -82,7 +82,7 @@ vbi_send(struct vbi *vbi, int type, int i1, int i2, int i3, void *p1)
     ev->i3 = i3;
     ev->p1 = p1;
 
-    for (cl = $ vbi->clients->first; cln = $ cl->node->next; cl = cln)
+    for (cl = PTR vbi->clients->first; cln = PTR cl->node->next; cl = cln)
 	cl->handler(cl->data, ev);
 }
 
@@ -449,7 +449,7 @@ vbi_del_handler(struct vbi *vbi, void *handler, void *data)
 {
     struct vbi_client *cl;
 
-    for (cl = $ vbi->clients->first; cl->node->next; cl = $ cl->node->next)
+    for (cl = PTR vbi->clients->first; cl->node->next; cl = PTR cl->node->next)
 	if (cl->handler == handler && cl->data == data)
 	{
 	    dl_remove(cl->node);
@@ -468,9 +468,9 @@ set_decode_parms(struct vbi *vbi, struct v4l2_vbi_format *p)
     int soc, eoc;	// start/end of clock run-in
     int bpl;		// bytes per line
 
-    if (p->sample_format != V4L2_VBI_SF_UBYTE)
+    if (p->sample_format != V4L2_PIX_FMT_GREY)
     {
-	error("v4l2: unsupported vbi data format");
+	error("v4l2: unsupported vbi data format 0x%08lx", p->sample_format);
 	return -1;
     }
 
@@ -526,13 +526,14 @@ setup_dev(struct vbi *vbi)
     struct v4l2_format v4l2_format[1];
     struct v4l2_vbi_format *vbifmt = &v4l2_format->fmt.vbi;
 
+    v4l2_format->type = V4L2_BUF_TYPE_VBI_CAPTURE;
     if (ioctl(vbi->fd, VIDIOC_G_FMT, v4l2_format) == -1
-	|| v4l2_format->type != V4L2_BUF_TYPE_VBI)
+	|| v4l2_format->type != V4L2_BUF_TYPE_VBI_CAPTURE)
     {
 	// not a v4l2 device.  assume bttv and create a standard fmt-struct.
 	int size;
 
-	vbifmt->sample_format = V4L2_VBI_SF_UBYTE;
+	vbifmt->sample_format = V4L2_PIX_FMT_GREY;
 	vbifmt->sampling_rate = 35468950;
 	vbifmt->samples_per_line = 2048;
 	vbifmt->offset = 244;
