@@ -31,11 +31,12 @@ int bell = -1;
 
 static struct dl_head dpys[1];		/* list of all displays */
 
+static void xio_timer(void *data, int fd);
+static void handle_event(struct xio *xio, int fd);
 
 static int
 timer_init(int argc, char **argv)
 {
-    static void xio_timer();
     int p[2], timer_pid, i;
 
     if (pipe(p) == -1)
@@ -160,7 +161,6 @@ struct xio *
 xio_open_dpy(char *dpy, int argc, char **argv)
 {
     XClassHint classhint[1];
-    static void handle_event(); //forward ref
     struct xio *xio;
 
     if (local_init(argc, argv) == -1)
@@ -197,7 +197,7 @@ xio_open_dpy(char *dpy, int argc, char **argv)
     if (fdset_add_fd(fds, xio->fd, handle_event, xio) == -1)
 	goto fail3;
     
-    XAddConnectionWatch(xio->dpy, $ xlib_conn_watch, $ fds);
+    XAddConnectionWatch(xio->dpy, PTR xlib_conn_watch, PTR fds);
 	
     xio->icon = XCreateBitmapFromData(xio->dpy, xio->root,
 					icon_bits, icon_width, icon_height);
@@ -355,7 +355,7 @@ xio_close_dpy(struct xio *xio)
 	xio_close_win((struct xio_win *)xio->windows->first, 0);
 
     XDestroyWindow(xio->dpy, xio->group_leader);
-    XRemoveConnectionWatch(xio->dpy, $ xlib_conn_watch, $ fds);
+    XRemoveConnectionWatch(xio->dpy, PTR xlib_conn_watch, PTR fds);
     fdset_del_fd(fds, xio->fd);
     dl_remove(xio->node);
     free(xio);
@@ -664,8 +664,8 @@ for_all_windows(void (*func)(struct xio_win *xw), struct xio_win *except)
     struct xio *xio, *vtn;
     struct xio_win *xw, *vwn;
 
-    for (xio = $ dpys->first; vtn = $ xio->node->next; xio = vtn)
-	for (xw = $ xio->windows->first; vwn = $ xw->node->next; xw = vwn)
+    for (xio = PTR dpys->first; vtn = PTR xio->node->next; xio = vtn)
+	for (xw = PTR xio->windows->first; vwn = PTR xw->node->next; xw = vwn)
 	    if (xw != except)
 		func(xw);
 }
@@ -857,19 +857,19 @@ sel_do_conv(struct xio_win *xw, Window w, Atom type, Atom prop)
 	atoms[4] = xio->xa_multiple;
 	atoms[5] = xio->xa_timestamp;
 	XChangeProperty(xio->dpy, w, prop, type,
-				    32, PropModeReplace, $ atoms, NELEM(atoms));
+				32, PropModeReplace, PTR atoms, NELEM(atoms));
     }
     else if (type == xio->xa_timestamp)
     {
 	u32 t = xw->sel_set_t;
 
-	XChangeProperty(xio->dpy, w, prop, type, 32, PropModeReplace, $ &t, 1);
+	XChangeProperty(xio->dpy, w, prop, type, 32, PropModeReplace, PTR &t, 1);
     }
     else if (type == XA_COLORMAP)
     {
 	u32 t = xio->cmap;
 
-	XChangeProperty(xio->dpy, w, prop, type, 32, PropModeReplace, $ &t, 1);
+	XChangeProperty(xio->dpy, w, prop, type, 32, PropModeReplace, PTR &t, 1);
     }
     else if (type == XA_STRING || type == xio->xa_text)
     {
@@ -887,7 +887,7 @@ sel_do_conv(struct xio_win *xw, Window w, Atom type, Atom prop)
 
 	pm = sel_convert2pixmap(xw);
 
-	XChangeProperty(xio->dpy, w, prop, type, 32, PropModeReplace, $ &pm, 1);
+	XChangeProperty(xio->dpy, w, prop, type, 32, PropModeReplace, PTR &pm, 1);
 	//prop = XA_PIXMAP;
     }
     else if (type == xio->xa_multiple)
@@ -897,8 +897,8 @@ sel_do_conv(struct xio_win *xw, Window w, Atom type, Atom prop)
 
 	if (prop != None)
 	{
-	    if (Success == XGetWindowProperty(xio->dpy, w, prop,
-		0, 1024, 0, AnyPropertyType, $ &ty, $ &fo, &n, &b, $ &atoms))
+	    if (Success == XGetWindowProperty(xio->dpy, w, prop, 0, 1024, 0,
+			AnyPropertyType, PTR &ty, PTR &fo, &n, &b, PTR &atoms))
 	    {
 		if (fo == 32 && n%2 == 0)
 		{
@@ -907,7 +907,7 @@ sel_do_conv(struct xio_win *xw, Window w, Atom type, Atom prop)
 			    atoms[i] = None;
 		}
 		XChangeProperty(xio->dpy, w, prop, type, 32, PropModeReplace,
-			 $ atoms, n);
+								 PTR atoms, n);
 		XFree(atoms);
 	    }
 	}
@@ -931,7 +931,7 @@ sel_send(struct xio_win *xw, XSelectionRequestEvent *req)
     ev->target = req->target;
     ev->property = sel_do_conv(xw, req->requestor, req->target, req->property);
     ev->time = req->time;
-    XSendEvent(xw->xio->dpy, req->requestor, False, 0, $ ev);
+    XSendEvent(xw->xio->dpy, req->requestor, False, 0, PTR ev);
 }
 
 static void
@@ -945,8 +945,8 @@ sel_retrieve(struct xio_win *xw, Window w, Atom prop, int del)
     if (prop == None)
 	return;
 
-    if (Success == XGetWindowProperty(xio->dpy, w, prop,
-		0, 1024, del, AnyPropertyType, $ &ty, $ &fo, &n, &b, $ &data))
+    if (Success == XGetWindowProperty(xio->dpy, w, prop, 0, 1024, del,
+			AnyPropertyType, PTR &ty, PTR &fo, &n, &b, PTR &data))
     {
 	if (fo == 8 && n != 0)
 	{
@@ -1009,7 +1009,7 @@ handle_event(struct xio *xio, int fd)
 
     XNextEvent(xio->dpy, ev);
 
-    for (xw = $ xio->windows->first; xw->node->next; xw = $ xw->node->next)
+    for (xw = PTR xio->windows->first; xw->node->next; xw = PTR xw->node->next)
 	if (xw->win == ev->xany.window)
 	    break;
     if (xw->node->next == 0)
@@ -1179,7 +1179,7 @@ xio_event_loop(void)
 	    for_all_windows(xio_update_win, 0);
 
 	    f = 0;
-	    for (xio = $ dpys->first; vtn = $ xio->node->next; xio = vtn)
+	    for (xio = PTR dpys->first; vtn = PTR xio->node->next; xio = vtn)
 		while (XPending(xio->dpy))
 		{
 		    handle_event(xio, xio->fd);
